@@ -16,7 +16,6 @@ filterwarnings(action='ignore', module='.*OpenSSL.*')
 from twisted.protocols.ftp import FTPFactory, FTP, AUTH_FAILURE
 from twisted.internet import reactor
 from twisted.python import log as tlog
-from ftplib import FTP as FFTP
 from subprocess import Popen
 from os import path
 from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
@@ -65,7 +64,7 @@ class QFTPServer():
                     username = _q_s.username
                     password = _q_s.password
                     status = 'success'
-                _q_s.logs.info(['servers', {'server': 'ftp_server', 'action': 'login', 'status': status, 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                _q_s.logs.info({'server': 'ftp_server', 'action': 'login', 'status': status, 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
                 return AUTH_FAILURE
 
         class CustomFTPFactory(FTPFactory):
@@ -99,7 +98,7 @@ class QFTPServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'ftp_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'ftp_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -120,6 +119,7 @@ class QFTPServer():
 
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
+            from ftplib import FTP as FFTP
             _ip = ip or self.ip
             _port = port or self.port
             _username = username or self.username
