@@ -15,7 +15,6 @@ filterwarnings(action='ignore', module='.*OpenSSL.*')
 
 from twisted.internet.protocol import Protocol, Factory
 from twisted.internet import reactor
-from redis import StrictRedis
 from twisted.python import log as tlog
 from subprocess import Popen
 from os import path
@@ -65,7 +64,7 @@ class QRedisServer():
                         if _data[0::2][0][0] == '$' and len(_data[1::2][0]) == int(_data[0::2][0][1]):
                             return _count, _data[1::2][0]
                 except Exception as e:
-                    print(e)
+                    pass
 
                 return 0, ''
 
@@ -91,12 +90,12 @@ class QRedisServer():
                         username = _q_s.username
                         password = _q_s.password
                         status = 'success'
-                    _q_s.logs.info(['servers', {'server': 'redis_server', 'action': 'login', 'status': status, 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                    _q_s.logs.info({'server': 'redis_server', 'action': 'login', 'status': status, 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
 
             def connectionMade(self):
                 self._state = 1
                 self._variables = {}
-                _q_s.logs.info(['servers', {'server': 'redis_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
+                _q_s.logs.info({'server': 'redis_server', 'action': 'connection', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
 
             def dataReceived(self, data):
                 c, command = self.get_command(data)
@@ -129,7 +128,7 @@ class QRedisServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'redis_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'redis_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -139,8 +138,17 @@ class QRedisServer():
         else:
             self.redis_server_main()
 
+    def close_port(self):
+        ret = close_port_wrapper('redis_server', self.ip, self.port, self.logs)
+        return ret
+
+    def kill_server(self):
+        ret = kill_server_wrapper('redis_server', self.uuid, self.process)
+        return ret
+
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
+            from redis import StrictRedis
             _ip = ip or self.ip
             _port = port or self.port
             _username = username or self.username
@@ -151,14 +159,6 @@ class QRedisServer():
         except BaseException:
             pass
 
-    def close_port(self):
-        ret = close_port_wrapper('redis_server', self.ip, self.port, self.logs)
-        return ret
-
-    def kill_server(self):
-        ret = kill_server_wrapper('redis_server', self.uuid, self.process)
-        return ret
-
 
 if __name__ == '__main__':
     parsed = server_arguments()
