@@ -13,13 +13,11 @@
 from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*OpenSSL.*')
 
-from time import sleep
 from socketserver import TCPServer, StreamRequestHandler, ThreadingMixIn
 from struct import unpack
-from requests import get
 from os import path
 from subprocess import Popen
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
+from honeypots.helper import check_if_server_is_running, close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, set_local_vars, setup_logger
 from uuid import uuid4
 
 
@@ -56,7 +54,7 @@ class QSOCKS5Server():
                     return str(string)
 
             def handle(self):
-                _q_s.logs.info(['servers', {'server': 'socks5_server', 'action': 'connection', 'ip': self.client_address[0], 'port':self.client_address[1]}])
+                _q_s.logs.info({'server': 'socks5_server', 'action': 'connection', 'src_ip': self.client_address[0], 'src_port': self.client_address[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
                 v, m = unpack('!BB', self.connection.recv(2))
                 if v == 5:
                     if 2 in unpack('!' + 'B' * m, self.connection.recv(m)):
@@ -73,7 +71,7 @@ class QSOCKS5Server():
                                 username = _q_s.username
                                 password = _q_s.password
                                 status = 'success'
-                            _q_s.logs.info(['servers', {'server': 'socks5_server', 'action': 'login', 'status': status, 'ip': self.client_address[0], 'port':self.client_address[1], 'username':username, 'password':password}])
+                            _q_s.logs.info({'server': 'socks5_server', 'action': 'login', 'status': status, 'src_ip': self.client_address[0], 'src_port': self.client_address[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
 
                 self.server.close_request(self.request)
 
@@ -84,13 +82,6 @@ class QSOCKS5Server():
         server = ThreadingTCPServer((self.ip, self.port), CustomStreamRequestHandler)
         server.serve_forever()
 
-    def run_server(self, process=False, auto=False):
-        if process:
-            if self.close_port() and self.kill_server():
-                self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
-        else:
-            self.socks5_server_main()
-
     def run_server(self, process=False, auto=False):
         status = 'error'
         run = False
@@ -108,7 +99,7 @@ class QSOCKS5Server():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'socks5_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'socks5_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -118,17 +109,6 @@ class QSOCKS5Server():
         else:
             self.socks5_server_main()
 
-    def test_server(self, ip=None, port=None, username=None, password=None):
-        try:
-            sleep(2)
-            _ip = ip or self.ip
-            _port = port or self.port
-            _username = username or self.username
-            _password = password or self.password
-            get('https://yahoo.com', proxies=dict(http='socks5://{}:{}@{}:{}'.format(_username, _password, _ip, _port), https='socks5://{}:{}@{}:{}'.format(_username, _password, _ip, _port)))
-        except BaseException:
-            pass
-
     def close_port(self):
         ret = close_port_wrapper('socks5_server', self.ip, self.port, self.logs)
         return ret
@@ -137,6 +117,17 @@ class QSOCKS5Server():
         ret = kill_server_wrapper('socks5_server', self.uuid, self.process)
         return ret
 
+    def test_server(self, ip=None, port=None, username=None, password=None):
+        try:
+            from requests import get
+            _ip = ip or self.ip
+            _port = port or self.port
+            _username = username or self.username
+            _password = password or self.password
+            get('https://yahoo.com', proxies=dict(http='socks5://{}:{}@{}:{}'.format(_username, _password, _ip, _port), https='socks5://{}:{}@{}:{}'.format(_username, _password, _ip, _port)))
+        except BaseException:
+            pass
+
 
 if __name__ == '__main__':
     parsed = server_arguments()
